@@ -1,9 +1,12 @@
 
 from tesla.auth.modal import UserBaseModal
-from tesla.modal import Model, CharField, ListField, TextField, EmailField, PasswordField,DateField
+from tesla.modal import Model, CharField, ListField, TextField, EmailField, PasswordField,DateField, BooleanField
 
 from dataclasses import dataclass
-            
+
+# class Permission(Model):
+#     can_edit = BooleanField()
+#     can_create = 
             
 
 class User(UserBaseModal):
@@ -15,6 +18,8 @@ class User(UserBaseModal):
     dob = DateField()
     bio = TextField()
     
+    is_super_user = BooleanField()
+    
     
     @classmethod
     def __meta__(self):
