@@ -1,7 +1,7 @@
 from dataclasses import dataclass
 from tesla.exceptions import DatabaseException
 from tesla.modal import Model
-
+from argon2 import PasswordHasher 
 
 
 
@@ -14,12 +14,15 @@ class UserBaseModal(Model):
         
         existing_user = self.get(username = self.username)
         # print(existing_user.id != self.id)
+        ph = PasswordHasher()
         if existing_user and existing_user.id != self.id :
             raise DatabaseException('User with this username already exists')
         # hashes the password
         elif existing_user == None:
-            from argon2 import PasswordHasher
-            ph = PasswordHasher()
-            password = hash = ph.hash(self.password)
+            password = ph.hash(self.password)
             self.password = password
+        elif ph.check_needs_rehash(self.password):
+            password = ph.hash(self.password)
+            self.password = password
+        # elif ph.    
         return super().save()
\ No newline at end of file
