@@ -3,6 +3,25 @@ from tesla.response import HttpResponse
 from dataclasses import dataclass
 import os
 
+
+media_types = {
+    'video': ['mp4'],
+    'audio': ['mp3'],
+    'image': ['png', 'jpg', 'jpeg'],
+    'text': ['css', 'js', 'txt','json']
+    
+}
+
+def get_media_type(ex):
+    r = 'text/txt'
+    
+    for t, es in media_types.items():
+        
+        if ex.lower() in es:
+            r = f'{t}/{ex}'
+            
+            break
+    return r    
 @dataclass
 class StaticFiles:
     paths = ['./static/']
@@ -27,9 +46,10 @@ class StaticFiles:
             if os.path.isfile(path + filename):
                 # print(path)
                 filename = path + filename
-                with open(filename) as file:
+                with open(filename, 'rb') as file:
+                    # print(file.)
                     request.headers += [('cache-control', 'public, max-age=3256926')]
-                    return HttpResponse(request, file.read(), content_type=f'text/{filename.split(".")[-1]}')
+                    return HttpResponse(request, file.read(), content_type=get_media_type(filename.split(".")[-1]))
             
         return HttpResponse(request, f"invalidd address\n {filename}")
 
